pub mod directory_processor;
pub mod error;
pub mod file_type;
pub mod logging;
pub mod tools;

// Constants for file processing
pub const FILES_TO_CONVERT: [&str; 3] = ["odt", "doc", "docx"];
pub const FILES_TO_COPY: [&str; 9] = [
    "jpg", "jpeg", "png", "gif", "bmp", "tiff", "webp", "avif", "txt",
];
pub const PATHS_TO_IGNORE: [&str; 5] = [
    ".DS_Store",
    ".syncthing",
    ".sync-conflict-",
    ".stfolder",
    ".stversions",
];

// Re-export commonly used items
pub use crate::logging::LogConfig;
pub use log::{debug, error, info, warn};

/// Macro for logging with file and line information
#[macro_export]
macro_rules! log_detail {
    ($level:expr, $($arg:tt)+) => {
        log::log!(
            $level,
            "[{}:{}] {}",
            file!(),
            line!(),
            format_args!($($arg)+)
        );
    };
}

/// Macro for performance logging with timing information
#[macro_export]
macro_rules! log_timed {
    ($level:expr, $desc:expr, $body:expr) => {{
        let start = std::time::Instant::now();
        let result = $body;
        let duration = start.elapsed();
        log::log!($level, "{} completed in {:.2?}", $desc, duration);
        result
    }};
}
